/*
 * Copyright 2010 Google Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except
 * in compliance with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License
 * is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express
 * or implied. See the License for the specific language governing permissions and limitations under
 * the License.
 */
/*
 * Warning! This file is generated. Modify at your own risk.
 */

package com.google.api.services.urlshortener.model;

import com.google.api.client.json.GenericJson;

/**
 * Model definition for UrlHistory.
 *
 * <p> This is the Java data model class that specifies how to parse/serialize into the JSON that is
 * transmitted over HTTP when working with the URL Shortener API. For a detailed explanation see:
 * <a href="http://code.google.com/p/google-api-java-client/wiki/Json">http://code.google.com/p/google-api-java-client/wiki/Json</a>
 * </p>
 *
 * <p>
 * Upgrade warning: starting with version 1.12 {@code getResponseHeaders()} is removed, instead use
 * {@link com.google.api.client.http.json.JsonHttpRequest#getLastResponseHeaders()}
 * </p>
 *
 * @author Google, Inc.
 */
@SuppressWarnings("javadoc")
public final class UrlHistory extends GenericJson {

  /**
   * A list of URL resources.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private java.util.List<Url> items;

  static {
    // hack to force ProGuard to consider Url used, since otherwise it would be stripped out
    // see http://code.google.com/p/google-api-java-client/issues/detail?id=528
    com.google.api.client.util.Data.nullOf(Url.class);
  }

  /**
   * Number of items returned with each full "page" of results. Note that the last page could have
   * fewer items than the "itemsPerPage" value.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private Integer itemsPerPage;

  /**
   * The fixed string "urlshortener#urlHistory".
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String kind;

  /**
   * A token to provide to get the next page of results.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String nextPageToken;

  /**
   * Total number of short URLs associated with this user (may be approximate).
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private Integer totalItems;

  /**
   * A list of URL resources.
   * The value returned may be {@code null}.
   */
  public java.util.List<Url> getItems() {
    return items;
  }

  /**
   * A list of URL resources.
   * The value set may be {@code null}.
   */
  public UrlHistory setItems(java.util.List<Url> items) {
    this.items = items;
    return this;
  }

  /**
   * Number of items returned with each full "page" of results. Note that the last page could have
   * fewer items than the "itemsPerPage" value.
   * The value returned may be {@code null}.
   */
  public Integer getItemsPerPage() {
    return itemsPerPage;
  }

  /**
   * Number of items returned with each full "page" of results. Note that the last page could have
   * fewer items than the "itemsPerPage" value.
   * The value set may be {@code null}.
   */
  public UrlHistory setItemsPerPage(Integer itemsPerPage) {
    this.itemsPerPage = itemsPerPage;
    return this;
  }

  /**
   * The fixed string "urlshortener#urlHistory".
   * The value returned may be {@code null}.
   */
  public String getKind() {
    return kind;
  }

  /**
   * The fixed string "urlshortener#urlHistory".
   * The value set may be {@code null}.
   */
  public UrlHistory setKind(String kind) {
    this.kind = kind;
    return this;
  }

  /**
   * A token to provide to get the next page of results.
   * The value returned may be {@code null}.
   */
  public String getNextPageToken() {
    return nextPageToken;
  }

  /**
   * A token to provide to get the next page of results.
   * The value set may be {@code null}.
   */
  public UrlHistory setNextPageToken(String nextPageToken) {
    this.nextPageToken = nextPageToken;
    return this;
  }

  /**
   * Total number of short URLs associated with this user (may be approximate).
   * The value returned may be {@code null}.
   */
  public Integer getTotalItems() {
    return totalItems;
  }

  /**
   * Total number of short URLs associated with this user (may be approximate).
   * The value set may be {@code null}.
   */
  public UrlHistory setTotalItems(Integer totalItems) {
    this.totalItems = totalItems;
    return this;
  }

}
